@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2009 Ricardo Villalba <rvm@escomposlinux.org>
+    Copyright (C) 2006-2012 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include "images.h"
 #include "mediasettings.h"
 #include "paths.h"
+#include "vdpauproperties.h"
 
 #if USE_ALSA_DEVICES || USE_DSOUND_DEVICES
 #include "deviceinfo.h"
@@ -53,16 +54,22 @@ PrefGeneral::PrefGeneral(QWidget * parent, Qt::WindowFlags f)
 #endif
 
 	// Screensaver
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	screensaver_check->hide();
 #else
 	screensaver_group->hide();
 #endif
 
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+	vdpau_button->hide();
+#endif
+
 	// Channels combo
 	channels_combo->addItem( "2", MediaSettings::ChStereo );
 	channels_combo->addItem( "4", MediaSettings::ChSurround );
 	channels_combo->addItem( "6", MediaSettings::ChFull51 );
+	channels_combo->addItem( "7", MediaSettings::ChFull61 );
+	channels_combo->addItem( "8", MediaSettings::ChFull71 );
 
 	connect(vo_combo, SIGNAL(currentIndexChanged(int)),
             this, SLOT(vo_combo_changed(int)));
@@ -81,7 +88,7 @@ QString PrefGeneral::sectionName() {
 }
 
 QPixmap PrefGeneral::sectionIcon() {
-	return Images::icon("pref_general");
+	return Images::icon("pref_general", 22);
 }
 
 void PrefGeneral::retranslateStrings() {
@@ -90,6 +97,8 @@ void PrefGeneral::retranslateStrings() {
 	channels_combo->setItemText(0, tr("2 (Stereo)") );
 	channels_combo->setItemText(1, tr("4 (4.0 Surround)") );
 	channels_combo->setItemText(2, tr("6 (5.1 Surround)") );
+	channels_combo->setItemText(3, tr("7 (6.1 Surround)") );
+	channels_combo->setItemText(4, tr("8 (7.1 Surround)") );
 
 	int deinterlace_item = deinterlace_combo->currentIndex();
 	deinterlace_combo->clear();
@@ -116,7 +125,7 @@ void PrefGeneral::retranslateStrings() {
 	*/
 
 	mplayerbin_edit->setCaption(tr("Select the mplayer executable"));
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	mplayerbin_edit->setFilter(tr("Executables") +" (*.exe)");
 #else
 	mplayerbin_edit->setFilter(tr("All files") +" (*)");
@@ -150,16 +159,28 @@ void PrefGeneral::setData(Preferences * pref) {
 		} else {
 			vo = "directx,";
 		}
+#else
+#ifdef Q_OS_OS2
+		vo = "kva";
 #else
 		vo = "xv,";
+#endif
 #endif
 	}
 	setVO( vo );
 
 	QString ao = pref->ao;
-#ifndef Q_OS_WIN
-	if (ao.isEmpty()) ao = "alsa,";
+
+#ifdef Q_OS_OS2
+	if (ao.isEmpty()) {
+		if (pref->mplayer_detected_version >= MPLAYER_KAI_VERSION) {
+			ao = "kai";
+		} else {
+			ao = "dart";
+		}
+	}
 #endif
+
 	setAO( ao );
 
 	setRememberSettings( !pref->dont_remember_media_settings );
@@ -181,7 +202,7 @@ void PrefGeneral::setData(Preferences * pref) {
 	setAmplification( pref->softvol_max );
 	setInitialPostprocessing( pref->initial_postprocessing );
 	setInitialDeinterlace( pref->initial_deinterlace );
-	setInitialZoom( pref->initial_panscan_factor );
+	setInitialZoom( pref->initial_zoom_factor );
 	setDirectRendering( pref->use_direct_rendering );
 	setDoubleBuffer( pref->use_double_buffer );
 	setUseSlices( pref->use_slices );
@@ -189,13 +210,17 @@ void PrefGeneral::setData(Preferences * pref) {
 	setBlackbordersOnFullscreen( pref->add_blackborders_on_fullscreen );
 	setAutoq( pref->autoq );
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	setAvoidScreensaver( pref->avoid_screensaver );
 	setTurnScreensaverOff( pref->turn_screensaver_off );
 #else
 	setDisableScreensaver( pref->disable_screensaver );
 #endif
 
+#if !defined(Q_OS_WIN) && !defined(Q_OS_OS2)
+	vdpau = pref->vdpau;
+#endif
+
 	setAudioChannels( pref->initial_audio_channels );
 	setScaleTempoFilter( pref->use_scaletempo );
 
@@ -220,6 +245,11 @@ void PrefGeneral::getData(Preferences * pref) {
 		i.getInfo(); 
 		// Update the drivers list at the same time
 		//setDrivers( i.voList(), i.aoList() );
+#ifdef Q_OS_OS2
+		vo_list = i.voList();
+		ao_list = i.aoList();
+		updateDriverCombos();
+#endif
 	}
 
 	TEST_AND_SET(pref->use_screenshot, useScreenshots());
@@ -256,7 +286,7 @@ void PrefGeneral::getData(Preferences * pref) {
 	TEST_AND_SET(pref->softvol_max, amplification());
 	pref->initial_postprocessing = initialPostprocessing();
 	pref->initial_deinterlace = initialDeinterlace();
-	pref->initial_panscan_factor = initialZoom();
+	pref->initial_zoom_factor = initialZoom();
 	TEST_AND_SET(pref->use_direct_rendering, directRendering());
 	TEST_AND_SET(pref->use_double_buffer, doubleBuffer());
 	TEST_AND_SET(pref->use_slices, useSlices());
@@ -267,13 +297,17 @@ void PrefGeneral::getData(Preferences * pref) {
 	}
 	TEST_AND_SET(pref->autoq, autoq());
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	pref->avoid_screensaver = avoidScreensaver();
 	TEST_AND_SET(pref->turn_screensaver_off, turnScreensaverOff());
 #else
 	TEST_AND_SET(pref->disable_screensaver, disableScreensaver());
 #endif
 
+#if !defined(Q_OS_WIN) && !defined(Q_OS_OS2)
+	pref->vdpau = vdpau;
+#endif
+
 	pref->initial_audio_channels = audioChannels();
 	TEST_AND_SET(pref->use_scaletempo, scaleTempoFilter());
 
@@ -300,6 +334,14 @@ void PrefGeneral::updateDriverCombos() {
 			vo_combo->addItem( "directx (" + tr("slow") + ")", "directx:noaccel" );
 		}
 		else
+#else
+#ifdef Q_OS_OS2
+		if ( vo == "kva") {
+			vo_combo->addItem( "kva (" + tr("fast") + ")", "kva" );
+			vo_combo->addItem( "kva (" + tr("snap mode") + ")", "kva:snap" );
+			vo_combo->addItem( "kva (" + tr("slower dive mode") + ")", "kva:dive" );
+		}
+		else
 #else
 		/*
 		if (vo == "xv") vo_combo->addItem( "xv (" + tr("fastest") + ")", vo);
@@ -315,6 +357,7 @@ void PrefGeneral::updateDriverCombos() {
 		}
 		else
 #endif // USE_XV_ADAPTORS
+#endif
 #endif
 		if (vo == "x11") vo_combo->addItem( "x11 (" + tr("slow") + ")", vo);
 		else
@@ -330,6 +373,11 @@ void PrefGeneral::updateDriverCombos() {
 			vo_combo->addItem( "gl2 (yuv)", "gl2:yuv=3");
 		}
 		else
+		if (vo == "gl_tiled") {
+			vo_combo->addItem( vo, vo);
+			vo_combo->addItem( "gl_tiled (yuv)", "gl_tiled:yuv=3");
+		}
+		else
 		if (vo == "null" || vo == "png" || vo == "jpeg" || vo == "gif89a" || 
             vo == "tga" || vo == "pnm" || vo == "md5sum" ) 
 		{
@@ -344,6 +392,12 @@ void PrefGeneral::updateDriverCombos() {
 	for ( int n = 0; n < ao_list.count(); n++) {
 		ao = ao_list[n].name();
 		ao_combo->addItem( ao, ao );
+#ifdef Q_OS_OS2
+		if ( ao == "kai") {
+			ao_combo->addItem( "kai (" + tr("uniaud mode") + ")", "kai:uniaud" );
+			ao_combo->addItem( "kai (" + tr("dart mode") + ")", "kai:dart" );
+		}
+#endif
 #if USE_ALSA_DEVICES
 		if ((ao == "alsa") && (!alsa_devices.isEmpty())) {
 			for (int n=0; n < alsa_devices.count(); n++) {
@@ -417,10 +471,12 @@ QString PrefGeneral::VO() {
 	QString vo = vo_combo->itemData(vo_combo->currentIndex()).toString();
 	if (vo == "user_defined") {
 		vo = vo_user_defined_edit->text();
+		/*
 		if (vo.isEmpty()) {
 			vo = vo_combo->itemData(0).toString();
 			qDebug("PrefGeneral::VO: user defined vo is empty, using %s", vo.toUtf8().constData());
 		}
+		*/
 	}
 	return vo;
 }
@@ -429,10 +485,12 @@ QString PrefGeneral::AO() {
 	QString ao = ao_combo->itemData(ao_combo->currentIndex()).toString();
 	if (ao == "user_defined") {
 		ao = ao_user_defined_edit->text();
+		/*
 		if (ao.isEmpty()) {
 			ao = ao_combo->itemData(0).toString();
 			qDebug("PrefGeneral::AO: user defined ao is empty, using %s", ao.toUtf8().constData());
 		}
+		*/
 	}
 	return ao;
 }
@@ -685,7 +743,7 @@ bool PrefGeneral::startInFullscreen() {
 	return start_fullscreen_check->isChecked();
 }
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 void PrefGeneral::setAvoidScreensaver(bool b) {
 	avoid_screensaver_check->setChecked(b);
 }
@@ -740,6 +798,11 @@ void PrefGeneral::vo_combo_changed(int idx) {
 	bool visible = (vo_combo->itemData(idx).toString() == "user_defined");
 	vo_user_defined_edit->setShown(visible);
 	vo_user_defined_edit->setFocus();
+
+#ifndef Q_OS_WIN
+	bool vdpau_button_visible = (vo_combo->itemData(idx).toString() == "vdpau");
+	vdpau_button->setShown(vdpau_button_visible);
+#endif
 }
 
 void PrefGeneral::ao_combo_changed(int idx) {
@@ -749,6 +812,32 @@ void PrefGeneral::ao_combo_changed(int idx) {
 	ao_user_defined_edit->setFocus();
 }
 
+#ifndef Q_OS_WIN
+void PrefGeneral::on_vdpau_button_clicked() {
+	qDebug("PrefGeneral::on_vdpau_button_clicked");
+
+	VDPAUProperties d(this);
+
+	d.setffh264vdpau(vdpau.ffh264vdpau);
+	d.setffmpeg12vdpau(vdpau.ffmpeg12vdpau);
+	d.setffwmv3vdpau(vdpau.ffwmv3vdpau);
+	d.setffvc1vdpau(vdpau.ffvc1vdpau);
+	d.setffodivxvdpau(vdpau.ffodivxvdpau);
+
+	d.setDisableFilters(vdpau.disable_video_filters);
+
+	if (d.exec() == QDialog::Accepted) {
+		vdpau.ffh264vdpau = d.ffh264vdpau();
+		vdpau.ffmpeg12vdpau = d.ffmpeg12vdpau();
+		vdpau.ffwmv3vdpau = d.ffwmv3vdpau();
+		vdpau.ffvc1vdpau = d.ffvc1vdpau();
+		vdpau.ffodivxvdpau = d.ffodivxvdpau();
+
+		vdpau.disable_video_filters = d.disableFilters();
+	}
+}
+#endif
+
 void PrefGeneral::createHelp() {
 	clearHelp();
 
@@ -806,11 +895,23 @@ void PrefGeneral::createHelp() {
 		tr("Select the video output driver. %1 provides the best performance.")
 #ifdef Q_OS_WIN
 		  .arg("<b><i>directx</i></b>")
+#else
+#ifdef Q_OS_OS2
+		  .arg("<b><i>kva</i></b>")
 #else
 		  .arg("<b><i>xv</i></b>")
+#endif
 #endif
 		);
 
+#if !defined(Q_OS_WIN) && !defined(Q_OS_OS2)
+	/*
+	setWhatsThis(vdpau_filters_check, tr("Disable video filters when using vdpau"),
+		tr("Usually video filters won't work when using vdpau as video output "
+           "driver, so it's wise to keep this option checked.") );
+	*/
+#endif
+
 	setWhatsThis(postprocessing_check, tr("Enable postprocessing by default"),
 		tr("Postprocessing will be used by default on new opened files.") );
 
@@ -862,7 +963,7 @@ void PrefGeneral::createHelp() {
            "some video drivers (like gl) are already able to display the "
            "subtitles automatically in the black borders.") */ );
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 	setWhatsThis(turn_screensaver_off_check, tr("Switch screensaver off"),
 		tr("This option switches the screensaver off just before starting to "
            "play a file and switches it on when playback finishes. If this "
@@ -888,12 +989,20 @@ void PrefGeneral::createHelp() {
 	setWhatsThis(ao_combo, tr("Audio output driver"),
 		tr("Select the audio output driver.") 
 #ifndef Q_OS_WIN
+#ifdef Q_OS_OS2
+        + " " +
+		tr("%1 is the recommended one. %2 is only available on older MPlayer (before version %3)")
+           .arg("<b><i>kai</i></b>")
+           .arg("<b><i>dart</i></b>")
+           .arg(MPLAYER_KAI_VERSION)
+#else
         + " " + 
 		tr("%1 is the recommended one. Try to avoid %2 and %3, they are slow "
            "and can have an impact on performance.")
            .arg("<b><i>alsa</i></b>")
            .arg("<b><i>esd</i></b>")
            .arg("<b><i>arts</i></b>")
+#endif
 #endif
 		);
 
@@ -901,7 +1010,9 @@ void PrefGeneral::createHelp() {
 		tr("Check this option if you want to use the audio equalizer.") );
 
 	setWhatsThis(hwac3_check, tr("AC3/DTS pass-through S/PDIF"),
-		tr("Uses hardware AC3 passthrough") );
+		tr("Uses hardware AC3 passthrough.") + "<br>" +
+        tr("<b>Note:</b> none of the audio filters will be used when this "
+           "option is enabled.") );
 
 	setWhatsThis(channels_combo, tr("Channels by default"),
 		tr("Requests the number of playback channels. MPlayer "
