@@ -21,6 +21,7 @@
 
 #include "ui_prefinterface.h"
 #include "prefwidget.h"
+#include "config.h"
 
 class Preferences;
 
@@ -46,6 +47,7 @@ public:
 	bool guiChanged() { return gui_changed; }
 	bool styleChanged() { return style_changed; };
 	bool recentsChanged() { return recents_changed; };
+	bool urlMaxChanged() { return url_max_changed; };
 
 protected:
 	virtual void createHelp();
@@ -74,9 +76,6 @@ protected:
 	bool useSingleInstance();
 #endif
 
-	void setRecentsMaxItems(int n);
-	int recentsMaxItems();
-
 	void setSeeking1(int n);
 	int seeking1();
 
@@ -92,7 +91,9 @@ protected:
 	void setUpdateWhileDragging(bool);
 	bool updateWhileDragging();
 
+#ifdef SEEKBAR_RESOLUTION
 	void setRelativeSeeking(bool);
+#endif
 	bool relativeSeeking();
 
 	void setPreciseSeeking(bool);
@@ -122,11 +123,24 @@ protected:
 	bool floatingBypassWindowManager();
 #endif
 
+	// Privacy tab
+	void setRecentsMaxItems(int n);
+	int recentsMaxItems();
+
+	void setURLMaxItems(int n);
+	int urlMaxItems();
+
+	void setRememberDirs(bool b);
+	bool rememberDirs();
+
 protected slots:
 	void on_changeFontButton_clicked();
 #ifdef SINGLE_INSTANCE
 	void changeInstanceImages();
 #endif
+#ifdef SKINS
+	void GUIChanged(int index);
+#endif
 
 protected:
 	virtual void retranslateStrings();
@@ -137,6 +151,11 @@ private:
 	bool gui_changed;
 	bool style_changed;
 	bool recents_changed;
+	bool url_max_changed;
+
+#ifdef SKINS
+	int n_skins;
+#endif
 };
 
 #endif
